# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## 1.0.0 - 2022-12-17

### Added

- First fully functional version

[1.0.0]: https://github.com/vsego/howigothere/releases/tag/v1.0.0
